"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.cli = void 0;
const meow_1 = __importDefault(require("meow"));
const path_1 = __importDefault(require("path"));
const index_1 = require("./index");
exports.cli = meow_1.default(`
    Usage
      $ workspaces-to-typescript-project-references
 

    Options
      --root             [Path:string] Root directory of the monorepo. 
                         Default: current working directory

      --check            If set the flag, check only differences of tsconfig.json and does not update tsconfig.json.
                         If the check is failed, exit status 1. It is useful for testing.
       
      --plugin           [Path:string] Path to plugin script.
                         Load the plugin script as module and use it. 
                           
      --tsconfigPath     [Path:string] Use alternative config path inside the package. e.g.: tsconfig.test.json
                         Default: tsconfig.json

    Examples
      # Update project references in tsconfig.json
      $ workspaces-to-typescript-project-references
      # Test on CI
      $ workspaces-to-typescript-project-references --check
`, {
    flags: {
        root: {
            type: "string",
            default: process.cwd()
        },
        check: {
            type: "boolean",
            default: false
        },
        plugin: {
            type: "string",
            isMultiple: true
        },
        tsconfigPath: {
            type: "string",
            default: "tsconfig.json"
        }
    },
    autoHelp: true,
    autoVersion: true
});
exports.run = (_input = exports.cli.input, flags = exports.cli.flags) => __awaiter(void 0, void 0, void 0, function* () {
    const plugins = Array.isArray(flags.plugin)
        ? flags.plugin.map((pluginPath) => {
            const plugin = require(path_1.default.join(process.cwd(), pluginPath));
            if (typeof plugin.plugin !== "string") {
                throw new Error("plugin should export { plugin }.");
            }
            return plugin.plugin;
        })
        : undefined;
    const customTsConfigFinder = (location) => {
        return path_1.default.join(location, flags.tsconfigPath);
    };
    const result = index_1.toProjectReferences({
        rootDir: flags.root,
        checkOnly: flags.check,
        plugins,
        tsConfigPathFinder: flags.tsconfigPath ? customTsConfigFinder : undefined
    });
    if (result.ok) {
        return {
            exitStatus: 0,
            stdout: flags.check ? "" : "Update Project References!",
            stderr: null
        };
    }
    else if (result.aggregateError) {
        return {
            exitStatus: 1,
            stdout: null,
            stderr: result.aggregateError.message + "\n\n" + result.aggregateError.errors.join("\n")
        };
    }
    return {
        exitStatus: 0,
        stdout: null,
        stderr: null
    };
});
//# sourceMappingURL=cli.js.map